summaryrefslogtreecommitdiff
path: root/setup_native
diff options
context:
space:
mode:
authorRĂ¼diger Timm <rt@openoffice.org>2005-08-18 11:50:28 +0000
committerRĂ¼diger Timm <rt@openoffice.org>2005-08-18 11:50:28 +0000
commitf8755c0bb39adb724ff549b3c6328e01b9d574fe (patch)
tree3268d42542d40cfe772f2bd4b0f2ef8eb7ddda76 /setup_native
parent30876e82101e3f07330c42bd61f1b1875fbdd2e1 (diff)
INTEGRATION: CWS debianer (1.12.4); FILE MERGED
2005/08/08 09:14:56 obr 1.12.4.2: fixed patching of bootstraprc to work with all products 2005/08/03 11:44:17 obr 1.12.4.1: #i52569# patch soffice script to expand the LD_LIBRARY_PATH
Diffstat (limited to 'setup_native')
-rw-r--r--setup_native/scripts/install_solaris.sh16
1 files changed, 9 insertions, 7 deletions
diff --git a/setup_native/scripts/install_solaris.sh b/setup_native/scripts/install_solaris.sh
index 1c2dc6e92e40..4f63ea48d021 100644
--- a/setup_native/scripts/install_solaris.sh
+++ b/setup_native/scripts/install_solaris.sh
@@ -155,8 +155,9 @@ then
INSTALL_DIR=${INSTALL_ROOT}`pkgparam -f ${INSTALL_ROOT}/var/sadm/pkg/*core01/pkginfo BASEDIR`
# restore original "bootstraprc" prior to patching
mv -f ${INSTALL_DIR}/program/bootstraprc.orig ${INSTALL_DIR}/program/bootstraprc
+ mv -f ${INSTALL_DIR}/program/soffice.orig ${INSTALL_DIR}/program/soffice
# copy INST_RELEASE file
if [ ! -f ${INSTALL_ROOT}/var/sadm/system/admin/INST_RELEASE ]
@@ -195,11 +196,6 @@ else
echo "Path to the installation : " $INSTALL_ROOT
LD_PRELOAD_32=$GETUID_SO /usr/sbin/pkgadd -d ${PACKAGE_PATH} -R ${INSTALL_ROOT} ${PKG_LIST} ${GNOMEPKG} >/dev/null
-
- # Create symlinks in the program directory for all libraries installed to /usr
- for i in `cd ${INSTALL_ROOT}; find usr -name '*.so.*'`; do
- ln -s ../../../$i ${INSTALL_DIR}/program/`basename $i`
- done
fi
rm -f $GETUID_SO
@@ -227,9 +223,15 @@ fi
# patch the "bootstraprc" to create a self-containing installation
mv ${INSTALL_DIR}/program/bootstraprc ${INSTALL_DIR}/program/bootstraprc.orig
-sed 's/UserInstallation=$SYSUSERCONFIG\/.staroffice8/UserInstallation=$ORIGIN\/..\/UserInstallation/g' \
+sed 's/UserInstallation=$SYSUSERCONFIG.*/UserInstallation=$ORIGIN\/..\/UserInstallation/g' \
${INSTALL_DIR}/program/bootstraprc.orig > ${INSTALL_DIR}/program/bootstraprc
+# patch the LD_LIBRARY_PATH in the "soffice" script so that it finds a suitable libfreetype
+mv ${INSTALL_DIR}/program/soffice ${INSTALL_DIR}/program/soffice.orig
+sed 's| LD_LIBRARY_PATH=\"\$sd_prog\"| LD_LIBRARY_PATH=/usr/sfw/lib:"$sd_prog":"$sd_prog/../../../usr/sfw/lib"|' \
+${INSTALL_DIR}/program/soffice.orig > ${INSTALL_DIR}/program/soffice
+chmod a+x ${INSTALL_DIR}/program/soffice
+
echo
echo "Installation done ..."
exit 0
@@ -155,8 +155,9 @@ then
INSTALL_DIR=${INSTALL_ROOT}`pkgparam -f ${INSTALL_ROOT}/var/sadm/pkg/*core01/pkginfo BASEDIR`
- # restore original "bootstraprc" prior to patching
+ # restore original "bootstraprc" and "soffice" prior to patching
mv -f ${INSTALL_DIR}/program/bootstraprc.orig ${INSTALL_DIR}/program/bootstraprc